[Scummvm-git-logs] scummvm master -> 7ad8fe46106327b5464235ec0c75d1c770be519e

bonki bonki at users.noreply.github.com
Fri Feb 9 22:59:45 CET 2018


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
7ad8fe4610 TUCKER: Fix Bud drawn behind parts of statue in park


Commit: 7ad8fe46106327b5464235ec0c75d1c770be519e
    https://github.com/scummvm/scummvm/commit/7ad8fe46106327b5464235ec0c75d1c770be519e
Author: Adrian Frühwirth (bonki at users.noreply.github.com)
Date: 2018-02-09T22:52:34+01:00

Commit Message:
TUCKER: Fix Bud drawn behind parts of statue in park

Fixes Trac#10423.

Changed paths:
    engines/tucker/tucker.cpp


diff --git a/engines/tucker/tucker.cpp b/engines/tucker/tucker.cpp
index 06c7368..5e14f71 100644
--- a/engines/tucker/tucker.cpp
+++ b/engines/tucker/tucker.cpp
@@ -1809,12 +1809,16 @@ void TuckerEngine::drawBackgroundSprites() {
 }
 
 void TuckerEngine::drawCurrentSprite() {
-	// Workaround original game glitch: skip first bud frame drawing when entering location (tracker item #2597763)
+	// WORKAROUND: original game glitch
+	// Skip first Bud frame drawing when entering location
+	// Fixes SF#2597763
 	if ((_locationNum == 17 || _locationNum == 18) && _currentSpriteAnimationFrame == 16) {
 		return;
 	}
-	// Workaround original game glitch: location 14 contains some colors from [0xE0-0xF8] in a walkable area (tracker item #3106542)
-	const bool color248Only = (_locationNum == 14);
+	// WORKAROUND: original game glitch
+	// Locations 14 and 61 contain some colors from [0xE0-0xF8] in a walkable area
+	// Fixes SF#3106542 and Trac#10423
+	const bool color248Only = (_locationNum == 14 || _locationNum == 61);
 	SpriteFrame *chr = &_spriteFramesTable[_currentSpriteAnimationFrame];
 	int yPos = _yPosCurrent + _mainSpritesBaseOffset - 54 + chr->_yOffset;
 	int xPos = _xPosCurrent;





More information about the Scummvm-git-logs mailing list